@@ -442,6 +442,31 @@ mp_subtract(const MPNumber *x, const MPNumber *y, MPNumber *z)
 }
 
 
+void
+mp_sgn(const MPNumber *x, MPNumber *z)
+{
+    if (mp_is_zero(x))
+        mp_set_from_integer(0, z);
+    else if (mp_is_negative(x))
+        mp_set_from_integer(-1, z);
+    else
+        mp_set_from_integer(1, z);  
+}
+
+void
+mp_integer_component(const MPNumber *x, MPNumber *z)
+{
+    int i;
+
+    /* Clear fraction */
+    mp_set_from_mp(x, z);
+    for (i = z->exponent; i < MP_SIZE; i++)
+        z->fraction[i] = 0;
+    z->im_sign = 0;
+    z->im_exponent = 0;
+    memset(z->im_fraction, 0, sizeof(int) * MP_SIZE);
+}
+
 void
 mp_fractional_component(const MPNumber *x, MPNumber *z)
 {
@@ -1856,7 +1881,7 @@ mp_root(const MPNumber *x, int64_t n, MPNumber *z)
         mp_invert_sign(z, z);
     }
     else if (mp_is_complex(x) || mp_is_negative(x)) {
-        MPNumber r, theta, i;
+        MPNumber r, theta;
 
         mp_abs(x, &r);
         mp_arg(x, MP_RADIANS, &theta);
